@@ -1,27 +1,25 @@
 /*
  * Argument handling and main.
- * Copyright (c) 1995-2000, 2002 Markku Rossi.
+ * Copyright (c) 1995-2003 Markku Rossi.
  *
  * Author: Markku Rossi <mtr@iki.fi>
  */
 
 /*
- * This file is part of GNU enscript.
+ * This file is part of GNU Enscript.
  *
- * This program is free software; you can redistribute it and/or modify
+ * Enscript is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * Enscript is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with Enscript.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "gsint.h"
@@ -1129,10 +1127,10 @@ _("library directory.")));
     }
 
   /* Site config. */
-  (void) read_config (SYSCONFDIR, "enscriptsite.cfg");
+  read_config (SYSCONFDIR, "enscriptsite.cfg");
 
   /* Personal config. */
-  (void) read_config (passwd->pw_dir, ".enscriptrc");
+  read_config (cp, ".enscriptrc");
 
   /*
    * Options.
@@ -1546,9 +1544,13 @@ name             width\theight\tllx\tlly\turx\tury\n\
       buffer_append (&cmd, intbuf);
       buffer_append (&cmd, " ");
 
-      buffer_append (&cmd, "-Ddocument_title=\"");
-      buffer_append (&cmd, title);
-      buffer_append (&cmd, "\" ");
+      buffer_append (&cmd, "-Ddocument_title=\'");
+      if ((cp = shell_escape (title)) != NULL)
+	{
+	  buffer_append (&cmd, cp);
+	  free (cp);
+	}
+      buffer_append (&cmd, "\' ");
 
       buffer_append (&cmd, "-Dtoc=");
       buffer_append (&cmd, toc ? "1" : "0");
@@ -1565,8 +1567,14 @@ name             width\theight\tllx\tlly\turx\tury\n\
       /* Append input files. */
       for (i = optind; i < argc; i++)
 	{
-	  buffer_append (&cmd, " ");
-	  buffer_append (&cmd, argv[i]);
+	  char *cp;
+	  if ((cp = shell_escape (argv[i])) != NULL)
+	    {
+	      buffer_append (&cmd, " \'");
+	      buffer_append (&cmd, cp);
+	      buffer_append (&cmd, "\'");
+	      free (cp);
+	    }
 	}
 
       /* And do the job. */
@@ -1627,7 +1635,7 @@ name             width\theight\tllx\tlly\turx\tury\n\
 				 buffer_ptr (opts), buffer_len (opts));
 	    }
 
-	  buffer_append (&buffer, " \"%s\"");
+	  buffer_append (&buffer, " \'%s\'");
 
 	  input_filter = buffer_copy (&buffer);
 	  input_filter_stdin = "-";
@@ -1714,9 +1722,6 @@ name             width\theight\tllx\tlly\turx\tury\n\
 	      process_file (_("Table of Contents"), &is, 1);
 	      is_close (&is);
 	    }
-
-	  /* Clean up toc file. */
-	  fclose (toc_fp);
 	}
 
       /* Give trailer a chance to dump itself. */
@@ -2628,7 +2633,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
   --word-wrap                wrap long lines from word boundaries\n\
 "));
 
-  printf (_("\nReport bugs to mtr@iki.fi.\n"));
+  printf (_("\nReport bugs to %s.\n"), PACKAGE_BUGREPORT);
 }
 
 
@@ -2636,7 +2641,7 @@ static void
 version ()
 {
   printf ("%s\n\
-Copyright (C) 1999 Markku Rossi.\n\
+Copyright (C) 2003 Markku Rossi.\n\
 GNU enscript comes with NO WARRANTY, to the extent permitted by law.\n\
 You may redistribute copies of GNU enscript under the terms of the GNU\n\
 General Public License.  For more information about these matters, see\n\
